// src/index.ts
import { createRequire } from "module";
import { createSyncFn } from "synckit";
import { visit } from "unist-util-visit";
function parseMarkingToLines(markingLines) {
  if (!markingLines)
    return [];
  return markingLines.split(" ").filter(Boolean).map((mark) => markToLines(mark)).flat(1);
}
var markToLines = (mark) => {
  const reg = /(.*)={([\d,-]+)}/;
  const match = reg.exec(mark);
  const [_, className, lineInfoStr] = Array.from(match || []);
  if (!lineInfoStr) {
    console.warn("parase markToLines error, invalid code inline marking:", mark);
    return [];
  }
  const lineList = lineInfoStr.split(",").map((v) => v.split("-").map((v2) => parseInt(v2, 10))).map(([start, end]) => {
    return end ? [...Array.from({ length: end - start + 1 }, (_2, i) => start + i)] : [start];
  }).flat(1);
  return lineList.map((line) => ({
    line,
    classes: className ? [className] : ["highlighted"]
  }));
};
var ShikiRemarkPlugin = (options) => {
  const { themes = [], theme = "nord", generateMultiCode, highlightLines, langs } = options;
  const custHighlighter = options.highlighter;
  let syncRun;
  if (!custHighlighter) {
    const require2 = createRequire(import.meta.url);
    syncRun = createSyncFn(require2.resolve("./worker"));
    syncRun("getHighlighter", { langs, themes, theme });
  }
  function highlight(code, theme2, lang, lineOptions) {
    if (custHighlighter) {
      return custHighlighter.codeToHtml(code, { lang, theme: theme2, lineOptions });
    } else {
      return syncRun("codeToHtml", {
        code,
        theme: theme2,
        lang,
        lineOptions
      });
    }
  }
  return function(tree) {
    visit(tree, "code", visitor);
    function visitor(node) {
      let highlightHTML;
      const lineOptions = highlightLines && node.meta ? parseMarkingToLines(node.meta) : [];
      if (generateMultiCode) {
        const allHighlighted = themes.map((theme2) => {
          return highlight(node.value, theme2, node.lang || "text", lineOptions);
        });
        highlightHTML = `<div class="shiki-container">${allHighlighted.join("")}</div>`;
      } else {
        highlightHTML = highlight(node.value, theme, node.lang || "text", lineOptions);
      }
      node.type = "html";
      node.value = highlightHTML;
    }
  };
};
var src_default = ShikiRemarkPlugin;
export {
  src_default as default
};
